@@ -1,4 +1,4 @@
-/* file.c   by Michael Thorpe   2002-12-27 */
+/* file.c   by Michael Thorpe   2003-08-02 */
 
 #include <errno.h>
 #include <fcntl.h>
@@ -96,12 +96,8 @@ static int retr_cb(conn *c) {
       goto fail;
    while(davail(c,2*BUF_SIZE)) {
       buf=(char *)malloc(2*BUF_SIZE);
-      if(!buf) {
-/* FIXME: This should be a 451 then 226 (and there may be others like it!) */
-         putline(c,426,0);
-         z=0;
+      if(!buf)
          goto fail;
-      }
       l=read(c->fdf,buf,BUF_SIZE);
       if(l==-1)
          goto failfree;
